==> apache-servicecomb-java-chassis-distribution-3.1.1-src.zip: apache-servicecomb-java-chassis-distribution-3.1.1-src/service-registry/registry-local/src/main/java/org/apache/servicecomb/localregistry/LocalRegistryConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.localregistry;

import org.apache.servicecomb.config.DataCenterProperties;
import org.apache.servicecomb.core.provider.LocalOpenAPIRegistry;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

@Configuration
public class LocalRegistryConfiguration {
  @Bean
  public LocalRegistrationInstance localRegistrationInstance(
      Environment environment,
      DataCenterProperties dataCenterProperties, LocalOpenAPIRegistry localOpenAPIRegistry) {
    return new LocalRegistrationInstance(environment, dataCenterProperties, localOpenAPIRegistry);
  }

  @Bean
  public LocalRegistration localRegistration(LocalRegistrationInstance localRegistrationInstance) {
    return new LocalRegistration(localRegistrationInstance);
  }

  @Bean
  public LocalDiscovery localDiscovery() {
    return new LocalDiscovery();
  }

  @Bean
  public LocalRegistryStore localRegistryStore() {
    return new LocalRegistryStore();
  }
}

==> apache-servicecomb-java-chassis-distribution-3.3.0-src.zip: apache-servicecomb-java-chassis-distribution-3.3.0-src/service-registry/registry-local/src/main/java/org/apache/servicecomb/localregistry/LocalRegistryConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.localregistry;

import org.apache.servicecomb.config.DataCenterProperties;
import org.apache.servicecomb.core.provider.LocalOpenAPIRegistry;
import org.apache.servicecomb.registry.RegistrationId;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

@Configuration
public class LocalRegistryConfiguration {
  @Bean
  public LocalRegistrationInstance localRegistrationInstance(
      Environment environment,
      DataCenterProperties dataCenterProperties,
      LocalOpenAPIRegistry localOpenAPIRegistry,
      RegistrationId registrationId) {
    return new LocalRegistrationInstance(environment, dataCenterProperties, localOpenAPIRegistry, registrationId);
  }

  @Bean
  public LocalRegistration localRegistration(LocalRegistrationInstance localRegistrationInstance) {
    return new LocalRegistration(localRegistrationInstance);
  }

  @Bean
  public LocalDiscovery localDiscovery() {
    return new LocalDiscovery();
  }

  @Bean
  public LocalRegistryStore localRegistryStore() {
    return new LocalRegistryStore();
  }
}
